/*====================================================================

ObjectWeb Transaction Working Group API
Contact: http://www.objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Romain Rouvoy.
Contributor(s): ______________________________________.

---------------------------------------------------------------------
$Id: DependencyTypeWeakCausal.java,v 1.1.1.1 2003/12/01 15:14:19 rouvoy Exp $
====================================================================*/
package org.objectweb.transaction.lib.transaction;

import org.objectweb.transaction.api.dependency.DependencyType;

/**
 * DependencyType for a weak-causal inter-transactions dependency.</BR>
 * <b>Weak-causal Dependency</b>: This type of dependency has the same 
 * meaning as the causal dependency, but it is applied only if the 
 * transaction of the "caused" significant event is active.
 * @author <a href="mailto:Romain.Rouvoy@lifl.fr">Romain Rouvoy</a>
 * @version 0.1
 */
public class DependencyTypeWeakCausal 
  implements DependencyType 
{
    /** Int value for dependency type <i>Weak-Causal</i>. */
    public static final int value = DependencyTypeWeakCausal.class.getName().hashCode();

    /** Object value for dependency type <i>Weak-Causal</i>. */
    public static final DependencyType type = new DependencyTypeWeakCausal();

    /* (non-Javadoc)
     * @see org.objectweb.transaction.api.dependency.DependencyType#getValue()
     */
    public int getValue() {
        return value;
    }

    /* (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    public String toString() {
        return "Weak-Causal Transactions Dependency Type" ;
    }
}
